
Acknowledgements
================

This work was partially funded by grant EPSR EP/P006175/1 as well as the Molecular Sciences Software Institute (MolSSI).  Computing resources were provided in part by the University of Chicago Research Computing Center (RCC).
We also want to thank the following scientists for their input and advice:

- Prof. Dimitris Giannakis for help in implementing the automatic bandwidth selection algorithm.
